@@ -3,7 +3,7 @@ package Test::UseAllModules;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Exporter;
 
@@ -34,6 +34,10 @@ READ:
   }
   close $fh;
 
+  unless (@modules) {
+    plan skip_all => 'no pm files found under the lib directory';
+    exit;
+  }
   plan tests => scalar @modules;
 
   my @failed;
